@@ -18,12 +18,11 @@ pub async fn handler() {
 async fn main() {
     let targets_to_filter: EventFilters = Regex::new("filter_records_by_fields").unwrap().into();
     let event_fields_to_filter: EventFilters = Regex::new("password").unwrap().into();
-    let (slack_layer, mut background_worker) = SlackLayer::builder(targets_to_filter)
+    let (slack_layer, background_worker) = SlackLayer::builder(targets_to_filter)
         .event_by_field_filters(event_fields_to_filter)
         .build();
     let subscriber = Registry::default().with(slack_layer);
     tracing::subscriber::set_global_default(subscriber).unwrap();
-    background_worker.startup();
     handler().await;
-    background_worker.teardown().await;
+    background_worker.shutdown().await;
 }
